ForceGraphWidget class

Inheritance

Constructors

ForceGraphWidget({Key? key, required ForceGraphController controller, bool showControlBar = true, EdgeInsets controlBarSpacing = const EdgeInsets.all(8), Alignment? controlBarAlignment, Axis? controlBarDirection, Widget nodeTooltipBuilder(BuildContext context, ForceGraphNode node)?, Widget edgeTooltipBuilder(BuildContext context, ForceGraphEdge edge)?, double nodeTooltipSpacing = 15, Offset offsetCorrection(Offset position)?, double edgeTooltipSpacing = 20, Widget customControlBarBuilder(BuildContext context, ForceGraphController controller)?, FocusNode? focusNode, Widget contextMenuBuilder(BuildContext context, ForceGraphController controller, Offset position, VoidCallback dismiss)?, Color? defaultControlBarForegroundColor, Color? defaultControlBarBackgroundColor, void onSelectionChanged(List<ForceGraphNode>)?, void onSecondaryTappedNode(ForceGraphNode, Offset)?, bool? defaultControlBarAutoHide, bool defaultControlBarOpacityChangesEnabled = true, Color? selectionOverlayColor, Widget errorBuilder(BuildContext context, Object error)?, Widget loadingBuilder(BuildContext context, int? progressStep, int? total, double? progress)? = _kDefaultLoadingBuilder})
const

Properties

contextMenuBuilder → Widget Function(BuildContext context, ForceGraphController controller, Offset position, VoidCallback dismiss)?
final
controlBarAlignment → Alignment?
final
controlBarDirection → Axis?
final
controlBarSpacing → EdgeInsets
final
controller → ForceGraphController
final
customControlBarBuilder → Widget Function(BuildContext context, ForceGraphController controller)?
final
defaultControlBarAutoHide → bool?
final
defaultControlBarBackgroundColor → Color?
final
defaultControlBarForegroundColor → Color?
final
defaultControlBarOpacityChangesEnabled → bool
final
edgeTooltipBuilder → Widget Function(BuildContext context, ForceGraphEdge edge)?
final
edgeTooltipSpacing → double
final
errorBuilder → Widget Function(BuildContext context, Object error)
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder → Widget Function(BuildContext context, int? progressStep, int? total, double? progress)?
final
nodeTooltipBuilder → Widget Function(BuildContext context, ForceGraphNode node)?
final
nodeTooltipSpacing → double
final
offsetCorrection → Offset Function(Offset position)?
final
onSecondaryTappedNode → void Function(ForceGraphNode, Offset)?
final
onSelectionChanged → void Function(List<ForceGraphNode>)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionOverlayColor → Color?
final
showControlBar → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ForceGraphWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited